==> apo-ws-client-6.00.50.1-sources.jar: fr/univlorraine/apowsclient/interdit/DonneesInterditDTO.java <==

package fr.univlorraine.apowsclient.interdit;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DonneesInterditDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DonneesInterditDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codBlocage"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codEtu" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}integer"&gt;
 *               &lt;totalDigits value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codINE" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="11"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="libNom" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="30"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="libPrenom" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="20"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="dateNais" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="dateDebBlocage" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="dateFinBlocage" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codEtp" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="6"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="libCommentaire" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="60"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DonneesInterditDTO", namespace = "DonneesInterditDTO.interdit.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codBlocage",
    "codEtu",
    "codINE",
    "libNom",
    "libPrenom",
    "dateNais",
    "dateDebBlocage",
    "dateFinBlocage",
    "codEtp",
    "libCommentaire"
})
public class DonneesInterditDTO {

    @XmlElement(required = true)
    protected String codBlocage;
    @XmlElementRef(name = "codEtu", type = JAXBElement.class, required = false)
    protected JAXBElement<BigInteger> codEtu;
    @XmlElementRef(name = "codINE", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codINE;
    @XmlElementRef(name = "libNom", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libNom;
    @XmlElementRef(name = "libPrenom", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libPrenom;
    @XmlElementRef(name = "dateNais", type = JAXBElement.class, required = false)
    protected JAXBElement<String> dateNais;
    @XmlElement(required = true)
    protected String dateDebBlocage;
    @XmlElementRef(name = "dateFinBlocage", type = JAXBElement.class, required = false)
    protected JAXBElement<String> dateFinBlocage;
    @XmlElementRef(name = "codEtp", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codEtp;
    @XmlElementRef(name = "libCommentaire", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libCommentaire;

    /**
     * Obtient la valeur de la propriété codBlocage.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodBlocage() {
        return codBlocage;
    }

    /**
     * Définit la valeur de la propriété codBlocage.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodBlocage(String value) {
        this.codBlocage = value;
    }

    /**
     * Obtient la valeur de la propriété codEtu.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link BigInteger }{@code >}
     *     
     */
    public JAXBElement<BigInteger> getCodEtu() {
        return codEtu;
    }

    /**
     * Définit la valeur de la propriété codEtu.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link BigInteger }{@code >}
     *     
     */
    public void setCodEtu(JAXBElement<BigInteger> value) {
        this.codEtu = value;
    }

    /**
     * Obtient la valeur de la propriété codINE.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodINE() {
        return codINE;
    }

    /**
     * Définit la valeur de la propriété codINE.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodINE(JAXBElement<String> value) {
        this.codINE = value;
    }

    /**
     * Obtient la valeur de la propriété libNom.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibNom() {
        return libNom;
    }

    /**
     * Définit la valeur de la propriété libNom.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibNom(JAXBElement<String> value) {
        this.libNom = value;
    }

    /**
     * Obtient la valeur de la propriété libPrenom.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibPrenom() {
        return libPrenom;
    }

    /**
     * Définit la valeur de la propriété libPrenom.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibPrenom(JAXBElement<String> value) {
        this.libPrenom = value;
    }

    /**
     * Obtient la valeur de la propriété dateNais.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getDateNais() {
        return dateNais;
    }

    /**
     * Définit la valeur de la propriété dateNais.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setDateNais(JAXBElement<String> value) {
        this.dateNais = value;
    }

    /**
     * Obtient la valeur de la propriété dateDebBlocage.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDateDebBlocage() {
        return dateDebBlocage;
    }

    /**
     * Définit la valeur de la propriété dateDebBlocage.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDateDebBlocage(String value) {
        this.dateDebBlocage = value;
    }

    /**
     * Obtient la valeur de la propriété dateFinBlocage.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getDateFinBlocage() {
        return dateFinBlocage;
    }

    /**
     * Définit la valeur de la propriété dateFinBlocage.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setDateFinBlocage(JAXBElement<String> value) {
        this.dateFinBlocage = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodEtp(JAXBElement<String> value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété libCommentaire.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibCommentaire() {
        return libCommentaire;
    }

    /**
     * Définit la valeur de la propriété libCommentaire.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibCommentaire(JAXBElement<String> value) {
        this.libCommentaire = value;
    }

}

==> apo-ws-client-6.00.50.3-sources.jar: fr/univlorraine/apowsclient/interdit/DonneesInterditDTO.java <==

package fr.univlorraine.apowsclient.interdit;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DonneesInterditDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DonneesInterditDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codBlocage"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codEtu" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}integer"&gt;
 *               &lt;totalDigits value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codINE" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="11"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="libNom" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="30"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="libPrenom" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="20"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="dateNais" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="dateDebBlocage" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="dateFinBlocage" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codEtp" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="6"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="libCommentaire" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="60"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DonneesInterditDTO", namespace = "DonneesInterditDTO.interdit.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codBlocage",
    "codEtu",
    "codINE",
    "libNom",
    "libPrenom",
    "dateNais",
    "dateDebBlocage",
    "dateFinBlocage",
    "codEtp",
    "libCommentaire"
})
public class DonneesInterditDTO {

    @XmlElement(required = true)
    protected String codBlocage;
    @XmlElement(nillable = true)
    protected BigInteger codEtu;
    @XmlElement(nillable = true)
    protected String codINE;
    @XmlElement(nillable = true)
    protected String libNom;
    @XmlElement(nillable = true)
    protected String libPrenom;
    @XmlElement(nillable = true)
    protected String dateNais;
    @XmlElement(required = true)
    protected String dateDebBlocage;
    @XmlElement(nillable = true)
    protected String dateFinBlocage;
    @XmlElement(nillable = true)
    protected String codEtp;
    @XmlElement(nillable = true)
    protected String libCommentaire;

    /**
     * Obtient la valeur de la propriété codBlocage.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodBlocage() {
        return codBlocage;
    }

    /**
     * Définit la valeur de la propriété codBlocage.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodBlocage(String value) {
        this.codBlocage = value;
    }

    /**
     * Obtient la valeur de la propriété codEtu.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCodEtu() {
        return codEtu;
    }

    /**
     * Définit la valeur de la propriété codEtu.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCodEtu(BigInteger value) {
        this.codEtu = value;
    }

    /**
     * Obtient la valeur de la propriété codINE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodINE() {
        return codINE;
    }

    /**
     * Définit la valeur de la propriété codINE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodINE(String value) {
        this.codINE = value;
    }

    /**
     * Obtient la valeur de la propriété libNom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibNom() {
        return libNom;
    }

    /**
     * Définit la valeur de la propriété libNom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibNom(String value) {
        this.libNom = value;
    }

    /**
     * Obtient la valeur de la propriété libPrenom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibPrenom() {
        return libPrenom;
    }

    /**
     * Définit la valeur de la propriété libPrenom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibPrenom(String value) {
        this.libPrenom = value;
    }

    /**
     * Obtient la valeur de la propriété dateNais.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDateNais() {
        return dateNais;
    }

    /**
     * Définit la valeur de la propriété dateNais.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDateNais(String value) {
        this.dateNais = value;
    }

    /**
     * Obtient la valeur de la propriété dateDebBlocage.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDateDebBlocage() {
        return dateDebBlocage;
    }

    /**
     * Définit la valeur de la propriété dateDebBlocage.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDateDebBlocage(String value) {
        this.dateDebBlocage = value;
    }

    /**
     * Obtient la valeur de la propriété dateFinBlocage.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDateFinBlocage() {
        return dateFinBlocage;
    }

    /**
     * Définit la valeur de la propriété dateFinBlocage.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDateFinBlocage(String value) {
        this.dateFinBlocage = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété libCommentaire.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibCommentaire() {
        return libCommentaire;
    }

    /**
     * Définit la valeur de la propriété libCommentaire.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibCommentaire(String value) {
        this.libCommentaire = value;
    }

}
